<?php # $Id: lang_bg.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $

/**
 *  @version $Revision: 2054 $
 *  @author Ivan Cenov jwalker@hotmail.bg
 */

@define('PLUGIN_KARMA_NAME', '');
@define('PLUGIN_KARMA_BLAHBLAH', '        ');
@define('PLUGIN_KARMA_VOTETEXT', '   : ');
@define('PLUGIN_KARMA_RATE', '  : %s');
@define('PLUGIN_KARMA_VOTEPOINT_1', ' !');
@define('PLUGIN_KARMA_VOTEPOINT_2', '');
@define('PLUGIN_KARMA_VOTEPOINT_3', '');
@define('PLUGIN_KARMA_VOTEPOINT_4', '');
@define('PLUGIN_KARMA_VOTEPOINT_5', '');
@define('PLUGIN_KARMA_VOTED', '  "%s"  .');
@define('PLUGIN_KARMA_INVALID', '   .');
@define('PLUGIN_KARMA_ALREADYVOTED', '    .');
@define('PLUGIN_KARMA_NOCOOKIE', '     ,     .');
@define('PLUGIN_KARMA_CLOSED', '   (%s   )  .');
@define('PLUGIN_KARMA_ENTRYTIME', '    ');
@define('PLUGIN_KARMA_VOTINGTIME', '   ');
@define('PLUGIN_KARMA_ENTRYTIME_BLAHBLAH', '  ( )            ?  : 1440 ( ).');
@define('PLUGIN_KARMA_VOTINGTIME_BLAHBLAH', ' ( ),         .       -   ,  : 5 .     \'\'  .');
@define('PLUGIN_KARMA_TIMEOUT', '  :       .   %s .');
@define('PLUGIN_KARMA_CURRENT', ' : %2$s, %3$s ');
@define('PLUGIN_KARMA_EXTENDEDONLY', '    ');
@define('PLUGIN_KARMA_EXTENDEDONLY_BLAHBLAH', '  \'\'            .');
@define('PLUGIN_KARMA_MAXKARMA', '  ');
@define('PLUGIN_KARMA_MAXKARMA_BLAHBLAH', '  ,      -      ( : 7)');
@define('PLUGIN_KARMA_LOGGING', '  ');
@define('PLUGIN_KARMA_LOGGING_BLAHBLAH', '  \'\'       .');
@define('PLUGIN_KARMA_ACTIVE', '   ?');
@define('PLUGIN_KARMA_ACTIVE_BLAHBLAH', '  \'\'     .');
@define('PLUGIN_KARMA_VISITS', '       ?');
@define('PLUGIN_KARMA_VISITS_BLAHBLAH', '  \'\'         .');
@define('PLUGIN_KARMA_VISITSCOUNT', ' %4$s ');
@define('PLUGIN_KARMA_STATISTICS_VISITS_TOP', '- ');
@define('PLUGIN_KARMA_STATISTICS_VISITS_BOTTOM', '-  ');
@define('PLUGIN_KARMA_STATISTICS_VOTES_TOP', '  - ');
@define('PLUGIN_KARMA_STATISTICS_VOTES_BOTTOM', '  - ');
@define('PLUGIN_KARMA_STATISTICS_POINTS_TOP', '  - ');
@define('PLUGIN_KARMA_STATISTICS_POINTS_BOTTOM', '  - ');
@define('PLUGIN_KARMA_STATISTICS_VISITS_NO', '');
@define('PLUGIN_KARMA_STATISTICS_VOTES_NO', '');
@define('PLUGIN_KARMA_STATISTICS_POINTS_NO', '');

@define('PLUGIN_KARMA_STARRATING', '      ?');

@define('PLUGIN_KARMA_VISITS_LOGGEDIN_USERS', '     ?');
@define('PLUGIN_KARMA_VISITS_LOGGEDIN_USERS_BLAHBLAH', '  \'\',     ()   .');
